package com.kuyuntech.cofarcooking.device.sdk.devmode.core;

import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorDirections;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.WorkModes;
import com.kuyuntech.cofarcooking.device.sdk.eventbus.core.DevInfo;
import com.kuyuntech.cofarcooking.device.sdk.util.core.CofarSDK;

import java.util.TimerTask;

/**
 * @author marco
 * @date 2024/3/25 上午10:54
 */
public class CitrusJuicer extends BaseDevMode {

    private Long currentSec = 0l;

    private Long timeRemaining = 0l;

    private Thread thread;

    private boolean pasue = false;

    private boolean stop = false;

    public CitrusJuicer() {

        this.setMode(WorkModes.CITRUS_JUICER);


        //时间
        this.setMinTime(0);
        this.setMaxTime(90 * 60);
        this.setDefaultTime(5 * 60);
        this.setTimeChange(true);

        //电机
        this.setDefaultMotorGear(1);
        this.setMinMotorGear(1);
        this.setMaxMotorGear(2);
        this.setMotorDirection(MotorDirections.FORWARD);
        this.setMotorGearChange(true);
        this.setMotorDirectionChange(false);

        //温度
        this.setDefaultTemp(0);
        this.setMinTemp(0);
        this.setMaxTemp(0);
        this.setTempChange(false);
        this.setDiyCountDown(true);

    }

    @Override
    public void start() {
        currentSec = 0L;
        currentSec = 4L;
        CofarSDK.startNative();
        this.stop = false;
    }


    @Override
    public void onCountDown(TimerTask timer) {

        if (pasue) {
            CofarSDK.stop();
            return;
        }

        DevInfo devInfo = CofarSDK.devInfo();


        if (devInfo.getRemainTime() <= 0 && devInfo.getMode().isCountDown()) {
            CofarSDK.stop();
            timer.cancel();
            return;
        }


        if (stop) {
            CofarSDK.stop();
            timer.cancel();
            return;
        }

        devInfo.setRemainTime((short) (devInfo.getRemainTime() - 1));


        if (timeRemaining <= 0) {
            CofarSDK.pauseNatvie();
            timeRemaining = 5L;
        }

        if (timeRemaining == 4) {
            if (MotorDirections.REVERSE == CofarSDK.devInfo().getMotorDirection()) {
                CofarSDK.cfgMotorDirectionNative(MotorDirections.FORWARD);
            } else {
                CofarSDK.cfgMotorDirectionNative(MotorDirections.REVERSE);
            }

            CofarSDK.resumeNavtive();
        }


        currentSec++;
        timeRemaining--;

    }

    @Override
    public void pause() {
        this.pasue = true;
        CofarSDK.pauseNatvie();
    }

    @Override
    public void resume() {
        this.pasue = false;
        CofarSDK.resumeNavtive();
    }

    @Override
    public void stop() {
        this.stop = true;
        CofarSDK.stopNative();
        super.stop();
    }


}
